/* This file is included by help.c and man2hlp.c */

/* Some useful constants */
#define CHAR_NODE_END		'\04'
#define CHAR_LINK_START		'\01'
#define CHAR_LINK_POINTER	'\02'
#define CHAR_LINK_END		'\03'
#define CHAR_ALTERNATE		'\05'
#define CHAR_NORMAL		'\06'
#define CHAR_VERSION		'\07'
#define STRING_LINK_START	"\01"
#define STRING_LINK_POINTER	"\02"
#define STRING_LINK_END		"\03"
#define STRING_NODE_END		"\04"

void interactive_display (char *filename, char *node);
